package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.LzydUserMapper;
import com.ruoyi.system.domain.LzydUser;
import com.ruoyi.system.service.ILzydUserService;

/**
 * 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-04-07
 */
@Service
public class LzydUserServiceImpl implements ILzydUserService 
{
    @Autowired
    private LzydUserMapper lzydUserMapper;

    /**
     * 查询悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * 
     * @param id 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
ID
     * @return 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     */
    @Override
    public LzydUser selectLzydUserById(Long id)
    {
        return lzydUserMapper.selectLzydUserById(id);
    }

    /**
     * 查询悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
列表
     * 
     * @param lzydUser 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * @return 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     */
    @Override
    public List<LzydUser> selectLzydUserList(LzydUser lzydUser)
    {
        return lzydUserMapper.selectLzydUserList(lzydUser);
    }

    /**
     * 新增悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * 
     * @param lzydUser 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * @return 结果
     */
    @Override
    public int insertLzydUser(LzydUser lzydUser)
    {
        lzydUser.setCreateTime(DateUtils.getNowDate());
        return lzydUserMapper.insertLzydUser(lzydUser);
    }

    /**
     * 修改悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * 
     * @param lzydUser 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * @return 结果
     */
    @Override
    public int updateLzydUser(LzydUser lzydUser)
    {
        lzydUser.setUpdateTime(DateUtils.getNowDate());
        return lzydUserMapper.updateLzydUser(lzydUser);
    }

    /**
     * 批量删除悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     * 
     * @param ids 需要删除的悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
ID
     * @return 结果
     */
    @Override
    public int deleteLzydUserByIds(Long[] ids)
    {
        return lzydUserMapper.deleteLzydUserByIds(ids);
    }

    /**
     * 删除悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
信息
     * 
     * @param id 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
ID
     * @return 结果
     */
    @Override
    public int deleteLzydUserById(Long id)
    {
        return lzydUserMapper.deleteLzydUserById(id);
    }
}
