package com.ruoyi.system.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.LzydUser;
import com.ruoyi.system.service.ILzydUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
Controller
 * 
 * @author ruoyi
 * @date 2021-04-07
 */
@RestController
@RequestMapping("/system/lzyduser")
public class LzydUserController extends BaseController
{
    @Autowired
    private ILzydUserService lzydUserService;

    /**
     * 查询悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
列表
     */
    @PreAuthorize("@ss.hasPermi('system:lzyduser:list')")
    @GetMapping("/list")
    public TableDataInfo list(LzydUser lzydUser)
    {
        startPage();
        List<LzydUser> list = lzydUserService.selectLzydUserList(lzydUser);
        return getDataTable(list);
    }

    /**
     * 导出悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
列表
     */
    @PreAuthorize("@ss.hasPermi('system:lzyduser:export')")
    @Log(title = "悦动APP-用户信息记录 ", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LzydUser lzydUser)
    {
        List<LzydUser> list = lzydUserService.selectLzydUserList(lzydUser);
        ExcelUtil<LzydUser> util = new ExcelUtil<LzydUser>(LzydUser.class);
        return util.exportExcel(list, "lzyduser");
    }

    /**
     * 获取悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息
详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:lzyduser:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(lzydUserService.selectLzydUserById(id));
    }

    /**
     * 新增悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     */
    @PreAuthorize("@ss.hasPermi('system:lzyduser:add')")
    @Log(title = "悦动APP-用户信息记录 荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息 ", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LzydUser lzydUser)
    {
        return toAjax(lzydUserService.insertLzydUser(lzydUser));
    }

    /**
     * 修改悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     */
    @PreAuthorize("@ss.hasPermi('system:lzyduser:edit')")
    @Log(title = "悦动APP-用户信息记录 荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息 ", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LzydUser lzydUser)
    {
        return toAjax(lzydUserService.updateLzydUser(lzydUser));
    }

    /**
     * 删除悦动APP-用户信息记录
荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息

     */
    @PreAuthorize("@ss.hasPermi('system:lzyduser:remove')")
    @Log(title = "悦动APP-用户信息记录 荔枝悦动用户，主要包含用户的信息字段，如：账号密码头像手机号等信息 ", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(lzydUserService.deleteLzydUserByIds(ids));
    }
}
